==> openflowplugin-extension-nicira-0.8.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/nx/ct/tp/src/grouping/NxmNxCtTpSrc.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.ct.tp.src.grouping;
import java.lang.Integer;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.NxmNxCtTpSrcGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-match</b>
 * <pre>
 * container nxm-nx-ct-tp-src {
 *   leaf ct-tp-src {
 *     type uint16;
 *   }
 *   leaf mask {
 *     type uint16;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-match/nxm-nx-ct-tp-src-grouping/nxm-nx-ct-tp-src</i>
 *
 * <p>To create instances of this class use {@link NxmNxCtTpSrcBuilder}.
 * @see NxmNxCtTpSrcBuilder
 *
 */
public interface NxmNxCtTpSrc
    extends
    ChildOf<NxmNxCtTpSrcGrouping>,
    Augmentable<NxmNxCtTpSrc>
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("nxm-nx-ct-tp-src");

    /**
     * @return <code>java.lang.Integer</code> <code>ctTpSrc</code>, or <code>null</code> if not present
     */
    @Nullable Integer getCtTpSrc();
    
    /**
     * @return <code>java.lang.Integer</code> <code>mask</code>, or <code>null</code> if not present
     */
    @Nullable Integer getMask();

}

==> openflowplugin-extension-nicira-0.8.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/nx/ct/tp/src/grouping/NxmNxCtTpSrc.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.ct.tp.src.grouping;
import java.lang.Integer;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.NxmNxCtTpSrcGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-match</b>
 * <pre>
 * container nxm-nx-ct-tp-src {
 *   leaf ct-tp-src {
 *     type uint16;
 *   }
 *   leaf mask {
 *     type uint16;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-match/nxm-nx-ct-tp-src-grouping/nxm-nx-ct-tp-src</i>
 *
 * <p>To create instances of this class use {@link NxmNxCtTpSrcBuilder}.
 * @see NxmNxCtTpSrcBuilder
 *
 */
public interface NxmNxCtTpSrc
    extends
    ChildOf<NxmNxCtTpSrcGrouping>,
    Augmentable<NxmNxCtTpSrc>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nxm-nx-ct-tp-src");

    /**
     * @return <code>java.lang.Integer</code> <code>ctTpSrc</code>, or <code>null</code> if not present
     */
    @Nullable Integer getCtTpSrc();
    
    /**
     * @return <code>java.lang.Integer</code> <code>mask</code>, or <code>null</code> if not present
     */
    @Nullable Integer getMask();

}
